==> foundation-ui-components-1.25.0.tgz: package/src/common/toast/useToast.tsx <==
import { JSX } from 'react';
import { closeSnackbar, enqueueSnackbar, VariantType } from 'notistack';
import Fade from './Fade';
import NsIcon from '../icon/NsIcon';
import NsButton from '../button/NsButton';

type ToastActionLink = {
    label: string;
    onClick?: () => void;
};

export type ToastOptions = {
    className?: string;
    autoHideDuration?: number | null;
    persist?: boolean;
    showCloseIcon?: boolean;
    actions?: ToastActionLink[];
}


const useToast = () => {
    const closeToast = (toastId?: string) => {
        closeSnackbar(toastId);
    };
    const generateActionButtons = (showCloseIcon: boolean = false, variant: VariantType = 'success', actions?: ToastActionLink[]) => {
        let actionButtons: JSX.Element[] = [];
        if (actions?.length) {
            actionButtons = actions.map((action) => (
                <NsButton data-testid="action-button" variant="text" color={variant as any} key={action?.label} onClick={() => action.onClick?.()}>
                    {action.label}
                </NsButton>
            ));
        }
        if (showCloseIcon) {
            actionButtons.push (
                <NsButton variant="text" onClick={() => closeToast()}>
                    <NsIcon name="close" size="small" cursor="pointer" />
                </NsButton>
            );
        }
        return actionButtons?.length ? actionButtons : null;
    };
    const showToast = (variant: VariantType = 'default', message?: string, options?: ToastOptions) => {
        try {
            return enqueueSnackbar(message, {
                variant,
                ...options,
                anchorOrigin: { horizontal: 'center', vertical: 'bottom' },
                preventDuplicate: true,
                TransitionComponent: Fade,
                action: generateActionButtons(options?.showCloseIcon, variant, options?.actions),
            });
        } catch (err) {
            console.error('CFT::UI:COMPONENTS showToast should be used inside NsToastProvider');
        } 
    };
    
    return {
        showToast,
        closeToast
    };
};

export default useToast;

==> foundation-ui-components-1.26.1.tgz: package/src/common/toast/useToast.tsx <==
import { JSX } from 'react';
import { closeSnackbar, enqueueSnackbar, VariantType } from 'notistack';
import Fade from './Fade';
import NsIcon from '../icon/NsIcon';
import NsButton from '../button/NsButton';

type ToastActionLink = {
    label: string;
    onClick?: () => void;
};

export type ToastOptions = {
    className?: string;
    autoHideDuration?: number | null;
    persist?: boolean;
    showCloseIcon?: boolean;
    actions?: ToastActionLink[];
}


const useToast = () => {
    const closeToast = (toastId?: string) => {
        closeSnackbar(toastId);
    };
    const generateActionButtons = (showCloseIcon: boolean = false, variant: VariantType = 'success', actions?: ToastActionLink[]) => {
        let actionButtons: JSX.Element[] = [];
        if (actions?.length) {
            actionButtons = actions.map((action) => (
                <NsButton data-testid="action-button" variant="text" color={variant as any} key={action?.label} onClick={() => action.onClick?.()}>
                    {action.label}
                </NsButton>
            ));
        }
        if (showCloseIcon) {
            actionButtons.push (
                <NsButton variant="text" onClick={() => closeToast()}>
                    <NsIcon name="close" size="small" cursor="pointer" />
                </NsButton>
            );
        }
        return actionButtons?.length ? actionButtons : null;
    };
    const showToast = (variant: VariantType = 'default', message?: string, options?: ToastOptions) => {

        try {
            return enqueueSnackbar(<div className='toast-message-wrapper'>{message}</div>, {
                variant,
                ...options,
                anchorOrigin: { horizontal: 'center', vertical: 'bottom' },
                preventDuplicate: true,
                TransitionComponent: Fade,
                action: generateActionButtons(options?.showCloseIcon, variant, options?.actions),
            });
        } catch (err) {
            console.error('CFT::UI:COMPONENTS showToast should be used inside NsToastProvider');
        } 
    };
    
    return {
        showToast,
        closeToast
    };
};

export default useToast;
